@@ -86,8 +86,8 @@ enmtools.ecospat.id <- function(species.1, species.2, env, nreps = 99, layers =
   colnames(background.env) <- c("Species", "x", "y", names(env))
   background.env <- background.env[complete.cases(background.env),]
 
-  sp1.niche <- ecospat::ecospat.grid.clim.dyn(background.env[,4:5], sp1.bg.env[,4:5], sp1.env[,4:5], th.sp=th.sp, th.env=th.env, R=R)
-  sp2.niche <- ecospat::ecospat.grid.clim.dyn(background.env[,4:5], sp2.bg.env[,4:5], sp2.env[,4:5], th.sp=th.sp, th.env=th.env, R=R)
+  sp1.niche <- ecospat::ecospat.grid.clim.dyn(background.env[,4:5], sp1.bg.env[,4:5], sp1.env[,4:5], th.sp=th.sp, th.env=th.env)
+  sp2.niche <- ecospat::ecospat.grid.clim.dyn(background.env[,4:5], sp2.bg.env[,4:5], sp2.env[,4:5], th.sp=th.sp, th.env=th.env)
 
   eq <- ecospat::ecospat.niche.equivalency.test(sp1.niche, sp2.niche, rep=nreps)
 
@@ -112,7 +112,7 @@ enmtools.ecospat.id <- function(species.1, species.2, env, nreps = 99, layers =
     theme(plot.title = element_text(hjust = 0.5))
 
 
-  sp1.bg.points <- as.data.frame(terra::rast(sp1.niche$Z), xy = TRUE)
+  sp1.bg.points <- as.data.frame(sp1.niche$Z, xy = TRUE)
   colnames(sp1.bg.points) <- c("X", "Y", "Density")
   sp1.bg.plot <-  ggplot(data = sp1.bg.points, aes(y = .data$Y, x = .data$X)) +
     geom_raster(aes_string(fill = "Density")) +
@@ -121,7 +121,7 @@ enmtools.ecospat.id <- function(species.1, species.2, env, nreps = 99, layers =
     ggtitle(paste(species.1$species.name, "available environment")) +
     theme(plot.title = element_text(hjust = 0.5))
 
-  sp1.env.points <- as.data.frame(terra::rast(sp1.niche$z.uncor), xy = TRUE)
+  sp1.env.points <- as.data.frame(sp1.niche$z.uncor, xy = TRUE)
   colnames(sp1.env.points) <- c("X", "Y", "Density")
   sp1.env.plot <-  ggplot(data = sp1.env.points, aes(y = .data$Y, x = .data$X)) +
     geom_raster(aes_string(fill = "Density")) +
@@ -130,7 +130,7 @@ enmtools.ecospat.id <- function(species.1, species.2, env, nreps = 99, layers =
     ggtitle(paste(species.1$species.name, "occurrence in environment space")) +
     theme(plot.title = element_text(hjust = 0.5))
 
-  sp1.env.corr.points <- as.data.frame(terra::rast(sp1.niche$z.cor), xy = TRUE)
+  sp1.env.corr.points <- as.data.frame(sp1.niche$z.cor, xy = TRUE)
   colnames(sp1.env.corr.points) <- c("X", "Y", "Density")
   sp1.env.plot.corr <-  ggplot(data = sp1.env.corr.points, aes(y = .data$Y, x = .data$X)) +
     geom_raster(aes_string(fill = "Density")) +
@@ -139,7 +139,7 @@ enmtools.ecospat.id <- function(species.1, species.2, env, nreps = 99, layers =
     ggtitle(paste(species.1$species.name, "occurrence scaled by availability")) +
     theme(plot.title = element_text(hjust = 0.5))
 
-  sp2.bg.points <- as.data.frame(terra::rast(sp2.niche$Z), xy = TRUE)
+  sp2.bg.points <- as.data.frame(sp2.niche$Z, xy = TRUE)
   colnames(sp2.bg.points) <- c("X", "Y", "Density")
   sp2.bg.plot <-  ggplot(data = sp2.bg.points, aes(y = .data$Y, x = .data$X)) +
     geom_raster(aes_string(fill = "Density")) +
@@ -148,7 +148,7 @@ enmtools.ecospat.id <- function(species.1, species.2, env, nreps = 99, layers =
     ggtitle(paste(species.2$species.name, "available environment")) +
     theme(plot.title = element_text(hjust = 0.5))
 
-  sp2.env.points <- as.data.frame(terra::rast(sp2.niche$z.uncor), xy = TRUE)
+  sp2.env.points <- as.data.frame(sp2.niche$z.uncor, xy = TRUE)
   colnames(sp2.env.points) <- c("X", "Y", "Density")
   sp2.env.plot <-  ggplot(data = sp2.env.points, aes(y = .data$Y, x = .data$X)) +
     geom_raster(aes_string(fill = "Density")) +
@@ -157,7 +157,7 @@ enmtools.ecospat.id <- function(species.1, species.2, env, nreps = 99, layers =
     ggtitle(paste(species.2$species.name, "occurrence in environment space")) +
     theme(plot.title = element_text(hjust = 0.5))
 
-  sp2.env.corr.points <- as.data.frame(terra::rast(sp2.niche$z.cor), xy = TRUE)
+  sp2.env.corr.points <- as.data.frame(sp2.niche$z.cor, xy = TRUE)
   colnames(sp2.env.corr.points) <- c("X", "Y", "Density")
   sp2.env.plot.corr <-  ggplot(data = sp2.env.corr.points, aes(y = .data$Y, x = .data$X)) +
     geom_raster(aes_string(fill = "Density")) +
